@@ -11,12 +11,20 @@ use Exporter;
 # Load Perl modules.
 use bytes;
 
+# Declare global variable
+my $is_eval;
+
+# BEGIN block.
+BEGIN {
+    $is_eval = ((eval "require 'sys/ioctl.ph'") ? 1 : 0);
+};
+
 # Load required Perl header.
-require 'sys/ioctl.ph';
-die "NO TIOCGWINSZ" unless defined &TIOCGWINSZ;;
+# require 'sys/ioctl.ph';
+# die "missing sys/ioctl.ph or no TIOCGWINSZ" unless defined &TIOCGWINSZ;
 
 # Set the package version. 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -34,6 +42,10 @@ our @EXPORT = qw(
                  pixels
                  get_cursor_position
                  set_cursor_position
+                 echo_on
+                 echo_off 
+                 cursor_on
+                 cursor_off
 );
 
 # Define BEGIN block.
@@ -60,7 +72,7 @@ $ESC = "\033";
 #------------------------------------------------------------------------------# 
 sub clear_screen {
     # Clear screen.
-    my $escseq = "${CSI}2J${CSI}0;0H";
+    my $escseq = "${CSI}2J${CSI}1;1H";
     # Get length of the escape sequence.
     my $buflen = length($escseq);
     # Write escape sequence to STDOUT.
@@ -82,6 +94,54 @@ sub reset_screen {
     syswrite(STDOUT, $escseq, $buflen, 0);
 };
 
+#------------------------------------------------------------------------------# 
+# Subroutine cursor_on                                                         #
+#                                                                              #
+# Description:                                                                 # 
+# Shows the cursor in the terminal window. Perform a system call on stty. Use  #
+# stty for reading from tty and writing to tty. Redirect stderr to stdout.     #
+#------------------------------------------------------------------------------# 
+sub cursor_on {
+    # Show the cursor.
+    print "${CSI}?25h";
+};
+
+#------------------------------------------------------------------------------# 
+# Subroutine cursor_off                                                        #
+#                                                                              #
+# Description:                                                                 # 
+# Hides the cursor in the terminal window. Perform a system call on stty. Use  #
+# stty for reading from tty and writing to tty. Redirect stderr to stdout.     #
+#------------------------------------------------------------------------------# 
+sub cursor_off {
+    # Hides the cursor.
+    print "${CSI}?25l";
+};
+
+#------------------------------------------------------------------------------# 
+# Subroutine echo_on                                                           #
+#                                                                              #
+# Description:                                                                 # 
+# Shows user input in the terminal window. Perform a system call on stty. Use  #
+# stty for reading from tty and writing to tty. Redirect stderr to stdout.     #
+#------------------------------------------------------------------------------# 
+sub echo_on {
+    # Turn echo on.
+    system("stty echo </dev/tty >/dev/tty 2>&1");
+};
+
+#------------------------------------------------------------------------------# 
+# Subroutine echo_off                                                          #
+#                                                                              #
+# Description:                                                                 # 
+# Hides user input in the terminal window. Perform a system call on stty. Use  #
+# stty for reading from tty and writing to tty. Redirect stderr to stdout.     #
+#------------------------------------------------------------------------------# 
+sub echo_off {
+    # Turn echo off.
+    system("stty -echo </dev/tty >/dev/tty 2>&1");
+};
+
 #------------------------------------------------------------------------------# 
 # Subroutine get_cursor_position                                               #
 #                                                                              #
@@ -95,12 +155,10 @@ sub get_cursor_position {
     # Change the settings of the terminal window.
     system "stty cbreak -echo </dev/tty >/dev/tty 2>&1";
     # Print escape sequence.
-    #print STDOUT "\033[6n";
     print STDOUT "${CSI}6n";
     # Read chars von STDIN.
-    while ($chr ne "R") {
-        $seq .= getc STDIN;
-        $chr = substr($seq, -1);
+    while (($chr = getc(STDIN)) ne "R") {
+        $seq .= $chr;
     };
     # Restore the settings of the terminal window.
     system "stty -cbreak echo </dev/tty >/dev/tty 2>&1";
@@ -133,10 +191,17 @@ sub set_cursor_position {
 sub winsize {
     # Initialise the variable $winsize. 
     my $winsize = "";
-    # Check the ioctl call of TIOCGWINSZ.
-    my ($rows, $cols, $xpix, $ypix) = ((ioctl(STDOUT, TIOCGWINSZ(), $winsize)) ?
-                                       (unpack 'S4', $winsize) :
-                                       (map {$_ * 0} (1..4)));
+    my ($rows, $cols, $xpix, $ypix);
+    if ($is_eval eq 1) {
+        # Check the ioctl call of TIOCGWINSZ.
+        ($rows, $cols, $xpix, $ypix) = ((ioctl(STDOUT, TIOCGWINSZ(), $winsize))
+                                       ? (unpack 'S4', $winsize)
+                                       : (map {$_ * 0} (1..4)));
+    } else {
+        $winsize = `stty size`;
+        ($rows, $cols) = $winsize =~ m/(\d+) (\d+)/s;
+        ($rows, $cols, $xpix, $ypix) = ($rows, $cols, -1, -1);
+    };
     # Return rows, cols and xpix, ypix.
     return ($rows, $cols, $xpix, $ypix);
 };
